@@ -16,6 +16,20 @@ def register_admin_model(admin_model_class: type[BaseModelAdmin], model_classes:
         admin_models[model_class] = admin_model_class
 
 
+def unregister_admin_model(model_classes: list[Any]):
+    """This method is used to unregister an admin model.
+
+    :params admin_model_class: a class of admin model.
+    :params model_classes: a list of model classes.
+    :return: None.
+    """
+    from fastadmin.app import admin_models
+
+    for model_class in model_classes:
+        if model_class in admin_models:
+            del admin_models[model_class]
+
+
 def get_admin_models() -> dict[Any, type[BaseModelAdmin]]:
     """This method is used to get a dict of admin models.
 
